@@ -33,8 +33,20 @@ Auth = namedtuple("Auth", [
     "update_user_password",
     "create_magic_link", "create_access_token",
     "migrate_user_from_external_source", "create_org", "add_user_to_org",
-    "delete_user", "disable_user", "enable_user",
-    "allow_org_to_setup_saml_connection", "disallow_org_to_setup_saml_connection"
+    "update_org_metadata",
+    "delete_user", "disable_user", "enable_user", "disable_user_2fa",
+    "enable_user_can_create_orgs", "disable_user_can_create_orgs",
+    "allow_org_to_setup_saml_connection", "disallow_org_to_setup_saml_connection",
+
+    "fetch_api_key",
+    "fetch_current_api_keys",
+    "fetch_archived_api_keys",
+    "create_api_key",
+    "update_api_key",
+    "delete_api_key",
+    "validate_api_key",
+    "validate_personal_api_key",
+    "validate_org_api_key",
 ])
 
 
@@ -75,9 +87,22 @@ def init_auth(auth_url: str, api_key: str, token_verification_metadata: TokenVer
         migrate_user_from_external_source=auth.migrate_user_from_external_source,
         create_org=auth.create_org,
         add_user_to_org=auth.add_user_to_org,
+        update_org_metadata=auth.update_org_metadata,
         enable_user=auth.enable_user,
         disable_user=auth.disable_user,
         delete_user=auth.delete_user,
+        disable_user_2fa=auth.disable_user_2fa,
+        enable_user_can_create_orgs=auth.enable_user_can_create_orgs,
+        disable_user_can_create_orgs=auth.disable_user_can_create_orgs,
         allow_org_to_setup_saml_connection=auth.allow_org_to_setup_saml_connection,
         disallow_org_to_setup_saml_connection=auth.disallow_org_to_setup_saml_connection,
+        fetch_api_key=auth.fetch_api_key,
+        fetch_current_api_keys=auth.fetch_current_api_keys,
+        fetch_archived_api_keys=auth.fetch_archived_api_keys,
+        create_api_key=auth.create_api_key,
+        update_api_key=auth.update_api_key,
+        delete_api_key=auth.delete_api_key,
+        validate_api_key=auth.validate_api_key,
+        validate_personal_api_key=auth.validate_personal_api_key,
+        validate_org_api_key=auth.validate_org_api_key,
     )
